@@ -4,7 +4,7 @@
 modname = 'brainomics'
 distname = 'cubicweb-brainomics'
 
-numversion = (0, 11, 5)
+numversion = (0, 12, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -17,15 +17,16 @@ __depends__ =  {'cubicweb': '>= 3.18.5',
                 'cubicweb-questionnaire': '>= 0.7.0',
                 'cubicweb-neuroimaging': '>= 0.7.0',
                 'cubicweb-genomics': '>= 0.10.0',
-                'cubicweb-medicalexp': '>= 0.12.2',
+                'cubicweb-medicalexp': '>= 0.12.3',
                 'cubicweb-card': None,
                 'cubicweb-bootstrap': '>= 0.6.0',
                 'cubicweb-squareui': '>= 0.3.5',
                 'cubicweb-comment': None,
                 'cubicweb-jqplot': None,
                 'cubicweb-clinipath': '>= 0.2.2',
+                'cubicweb-vtimeline': '>= 0.5.0'
                 }
-__recommends__ = {'cubicweb-vtimeline': '>= 0.5.0'}
+__recommends__ = {}
 
 
 from os import listdir as _listdir
