@@ -27,3 +27,8 @@ set_property('ui.site-title', 'Brainomics')
 # Create cards
 create_entity('Card', content_format=u'text/html', title=u'index', wikiid=u'index',
               content=u"""The BRAINOMICS project is one of the projects chosen by the Agence nationale de la recherche (ANR) in the bioinformatics call of the Investissements d'avenir program.""")
+
+# Standard scores
+ecog = session.create_entity('ScoreDefinition', type=u'both', name=u'ECOG')
+lansky = session.create_entity('ScoreDefinition', type=u'both', name=u'Lansky')
+karnofsky = session.create_entity('ScoreDefinition', type=u'both', name=u'Karnofsky')
