@@ -108,6 +108,9 @@ class BrainomicsSchemaTC(CubicWebTC):
         # Delete Assessment first:
         req.execute('DELETE Assessment X WHERE X related_study Y, Y eid %(studeid)s',
                     {'studeid': study_eid})
+        # Also delete Admission, for cardinality constraints reasons:
+        req.execute('DELETE Admission X WHERE X admission_in Y, Y eid %(studeid)s',
+                    {'studeid': study_eid})
         req.execute('DELETE Study X WHERE X eid %(studeid)s', {'studeid': study_eid})
         self.commit()
         db_qrun = req.execute('Any X WHERE X is QuestionnaireRun')
