@@ -300,8 +300,12 @@ class BrainomicsResultsFileBox(component.CtxComponent):
         w(u'<ul>')
         for _file in _files:
             title = _file.dc_title().rsplit('/')[-1]
+            if _file.__regid__ == 'File':
+                icon = _file.view('icon')
+            else:
+                icon = u''
             w(u'<li>%s<a href="%s" title="%s">%s</a></li>'
-              % (_file.view('icon'), _file.absolute_url(vid='download'),
+              % (icon, _file.absolute_url(vid='download'),
                  xml_escape(title), xml_escape(title[:15]+'...')))
         w(u'</ul>')
         w(u'</div>')
@@ -335,8 +339,10 @@ class BrainomicsFilterBox(facets.FilterBox):
     def layout_widgets(self, w, wdgs):
         super(BrainomicsFilterBox, self).layout_widgets(w, wdgs)
         w(u'<div class="admintools">')
-        for comp in self._cw.vreg['dynamic-facet'].possible_objects(self._cw, rset=self.cw_rset):
-            comp.render(w=w)
+        dfreg = self._cw.vreg.get('dynamic-facet')
+        if dfreg:
+            for comp in dfreg.possible_objects(self._cw, rset=self.cw_rset):
+                comp.render(w=w)
         w(u'<div id="dynamic-facet-container"></div>')
         w(u'</div>')
 
