@@ -73,6 +73,11 @@ class GenomicMeasureOutOfContextView(BrainomicsAbstractOutOfContextView):
     icon = 'filter'
 
 
+class IHCMeasureOutOfContextView(BrainomicsAbstractOutOfContextView):
+    __select__ = BrainomicsAbstractOutOfContextView.__select__ & is_instance('IHCMeasure')
+    icon = 'filter'
+
+
 class GeneContextView(BrainomicsAbstractOutOfContextView):
     __select__ = BrainomicsAbstractOutOfContextView.__select__ & is_instance('Gene')
     icon = 'link'
