@@ -84,7 +84,7 @@ class BrainomicsIndexView(IndexView):
     def get_clinical_data_etypes(self):
         measures = set([(r.type, None, None) for r in self._cw.vreg.schema.rschema('concerns').subjects()])
         return chain(((etype, None, None) for etype in ('Study', 'Subject', 'Therapy',
-                      'Diagnostic', 'DrugTake')), measures)
+                      'Diagnostic', 'DrugTake', 'Biopsy')), measures)
 
     def get_thesaurus_data_etypes(self):
         return ((etype, None, None) for etype in ('Disease', 'BodyLocation', 'MedicalTechnique', 'Drug'))
@@ -99,6 +99,7 @@ class BrainomicsIndexView(IndexView):
         self.display_dashboards()
         w(u'</div>')
         # Patients
+        w(u'<div class="row">')
         w(u'<div class="col-md-6">')
         self.display_list_panel(self.get_clinical_data_etypes(),
                                 self._cw._(u'Patient directory-based search'),
@@ -111,6 +112,7 @@ class BrainomicsIndexView(IndexView):
                                 self._cw._('Access thesaurus-based data for '
                                            'transversal retrieval'))
         w(u'</div>')
+        w(u'</div>')
         # Examples
         self.display_examples()
 
