@@ -18,11 +18,9 @@
 
 from logilab.mtconverter import xml_escape
 
-from cubicweb.predicates import is_instance, nonempty_rset
+from cubicweb.predicates import is_instance, nonempty_rset, relation_possible
 from cubicweb.web import component
 
-from cubes.brainomics.schema import COMMENTED_ENTITIES, WIKI_ENTITIES
-
 
 ###############################################################################
 ### TABBLABLE SELECTION COMPONENT #############################################
@@ -74,7 +72,7 @@ class AbstractBrainomicsTabblable(component.EntityCtxComponent):
 ###############################################################################
 class BrainomicsTabblableComment(AbstractBrainomicsTabblable):
     """ Component used to display a tab with comment. """
-    __select__ = AbstractBrainomicsTabblable.__select__ & is_instance(*COMMENTED_ENTITIES)
+    __select__ = AbstractBrainomicsTabblable.__select__ & relation_possible('comments', role='object')
     __regid__ = 'entity-comment-tab'
 
     def get_title(self):
@@ -94,7 +92,7 @@ class BrainomicsTabblableComment(AbstractBrainomicsTabblable):
 ###############################################################################
 class BrainomicsTabblableWiki(AbstractBrainomicsTabblable):
     """ Component used to display a tab with wiki. """
-    __select__ = AbstractBrainomicsTabblable.__select__ & is_instance(*WIKI_ENTITIES)
+    __select__ = AbstractBrainomicsTabblable.__select__ & relation_possible('wiki')
     __regid__ = 'entity-wiki-tab'
 
     def get_title(self):
@@ -114,7 +112,7 @@ class BrainomicsTabblableWiki(AbstractBrainomicsTabblable):
 ### TABBLABLE COMPONENTS - TIMELINE ###########################################
 ###############################################################################
 class BrainomicsTabblableTimeline(AbstractBrainomicsTabblable):
-    """ Component used to display a tab with wiki. """
+    """ Component used to display a tab with a timeline. """
     __select__ = AbstractBrainomicsTabblable.__select__ & is_instance('Subject')
     __regid__ = 'entity-timeline-tab'
 
@@ -122,14 +120,7 @@ class BrainomicsTabblableTimeline(AbstractBrainomicsTabblable):
         return self._cw._('Timeline')
 
     def render_content(self, w, **kwargs):
-        entity = self.cw_rset.get_entity(0, 0)
-        assessments_rset = self._cw.execute('Any X, D WHERE S concerned_by X, X datetime D, S eid %(eid)s',
-                                            {'eid': entity.eid})
-        if assessments_rset:
-            w(self._cw.view('vtimeline', rset=assessments_rset,
-                            custom_settings={'width': '90%'}))
-        else:
-            w(u'<div>%s</div>' % self._cw._('No assessments available'))
+        w(self._cw.view('vtimeline', rset=self.cw_rset))
 
 
 ###############################################################################
@@ -233,13 +224,9 @@ class BrainomicsTabblableAssessmentView(AbstractBrainomicsTabblable):
         entity = self.cw_rset.get_entity(0, 0)
         rset = self._cw.execute('Any X WHERE S concerned_by X, S eid %(e)s', {'e': entity.eid})
         if rset:
-            w(u'<h3>%s</h3>' % xml_escape(self._cw._('Detailed Assessments')))
-            w(self._cw.view('list', rset=rset))
+            w(self._cw.view('sameetypelist', rset=rset))
 
 
-###############################################################################
-### REGISTRATION CALLBACK #####################################################
-###############################################################################
 def registration_callback(vreg):
     vreg.register_all(globals().values(), __name__,
                       (BrainomicsTabblableTimeline,))
