@@ -177,6 +177,15 @@ _pvdc.tag_subject_of(('ExternalResource', 'related_study', '*'),
                      {'vid': 'incontext', 'label': _('Study')})
 
 
+###############################################################################
+### IHCMEASURE ################################################################
+###############################################################################
+_pvs.tag_object_of(('*', 'generates', 'IHCMeasure'), 'attributes')
+_pvs.tag_subject_of(('IHCResult', 'related_measure', 'IHCMeasure'), 'attributes')
+_pvs.tag_object_of(('IHCResult', 'related_measure', 'IHCMeasure'), 'relations')
+_pvdc.tag_object_of(('IHCResult', 'related_measure', 'IHCMeasure'), {'vid': 'table'})
+
+
 ###############################################################################
 ### GENOMICMEASURE ############################################################
 ###############################################################################
